# folium_maps
Данный репозиторий является клоном библиотеки `folium`, но с не опенсорсными оффлайн картами и маркерами. Ссылка на оригинальную библиотеку: https://pypi.org/project/folium/

Сам клон библиотеки доступен на PyPI по ссылке: https://pypi.org/project/folium_maps/

## В чем разница между оригинальной библиотекой и folium_maps
В первую очередь разница в картах и js-файлах, которые отвечают за отрисовку карты в html. Данные для карт лежат на s3 Практикума: https://admin.praktikum.yandex-team.ru/explorer/code?prefix=data_faculty%2Ffolium%2F&filterDir=

Поскольку мы используем кастомные маркеры, то изменение цвета и размера маркера не доступно. Также предустановленная версия карты только для Москвы, другие регионы не доступны.

Сами карты рендерятся примерно 2 минуты, поскольку изначально скачиваются из s3. Поскольку карты лежат на s3 Практикума, то использование библиотеки возможно только в контуре Яндекс Практикума: на платформе или с использованием vpn-токена. Карты требуют достаточно много ресурсов. Поэтому для авторов заданий на Яндекс Практикуме рекомендовано создавать .ipynb-тетрадки с отрисовкой не более 3 карт в одной.

## Как обновить версию библиотеки на PyPI
1. Внести изменения в папке `folium_maps` и проверить их работу локально
2. Поменять версию и параметры (при необходимости) в файле `setup.py` или `setup.cfg` (при необходимости)
3. Собрать новую версию библиотеки с помощью команды:
```
python setup.py sdist bdist_wheel
```
4. Загрузить все версии библиотеки на PyPI с помощью команды:
```
twine upload --repository pypi dist/*
```
Параметры для аккаунта data.practicum:
```
  username = __token__
  password = pypi-AgEIcHlwaS5vcmcCJDZkYzNhZTMwLWE2OWQtNDgwNS04Nzg2LTRhOTlmMDcxMTUwNgACKlszLCI3YTZjMDYwYy1jNTVlLTQzY2MtOTEzMC05MjViYTU5MDZlNjEiXQAABiBiVum5e1MJPbbbwIlqUwqijDrGbhP-G4u9z6YF6IwOcQ
```